@@ -1,5 +1,10 @@
 #!/bin/sh
 
+libtoolize --force || {
+	echo "libtoolize failed, exiting..."
+	exit 1
+}
+
 aclocal $ACLOCAL_FLAGS || {
     echo "aclocal \$ACLOCAL_FLAGS where \$ACLOCAL_FLAGS= failed, exiting..."
     exit 1
