@@ -6,6 +6,7 @@
 #include <time.h>
 #include <sys/types.h>
 #include <unistd.h>
+#include <sys/time.h>
 
 #include "lrdf.h"
 #include "lrdf_md5.h"
@@ -68,13 +69,15 @@ static inline lrdf_hash lrdf_gen_hash(const char *str)
 void lrdf_init()
 {
     unsigned int i;
+    struct timeval tv;
 
     raptor_init();
     lrdf_more_triples(256);
 
     /* A UID to add to genids to make them safer */
+    gettimeofday(&tv, NULL);
     lrdf_uid = (unsigned int) getpid();
-    lrdf_uid ^= (unsigned int) time(NULL);
+    lrdf_uid ^= (unsigned int) tv.tv_usec;
 
     /* Global value for the hash of rdf:Resource, saves time */
     rdf_resource_h = lrdf_gen_hash(RDF_RESOURCE);
@@ -585,7 +588,7 @@ int lrdf_read_file(const char *uri)
 
 int lrdf_read_file_intl(const char *uri)
 {
-    raptor_parser *parser;
+    raptor_parser *parser = NULL;
     raptor_uri *ruri, *furi;
     lrdf_hash source;
 
@@ -609,6 +612,7 @@ int lrdf_read_file_intl(const char *uri)
     raptor_set_error_handler(parser, parser, lrdf_error_handler);
     raptor_set_warning_handler(parser, NULL, lrdf_warning_handler);
     raptor_set_statement_handler(parser, &source, lrdf_store);
+    raptor_set_default_generate_id_parameters(parser, NULL, ++lrdf_uid);
 
     if (raptor_parse_file(parser, furi, ruri)) {
 	raptor_free_uri(furi);
